@@ -9,8 +9,9 @@ from abc import ABC, abstractmethod
 
 import numpy as np
 import scipy.stats as sts
+import scipy.optimize
 
-from .settings import SHAPE_STRING, LOCATION_STRING, SCALE_STRING
+from .settings import SHAPE_STRING, LOCATION_STRING, SCALE_STRING, SHAPE2_STRING
 from .params import FunctionParam, ConstantParam, Wrapper
 
 __all__ = ["Distribution", "ParametricDistribution", "WeibullDistribution",
@@ -39,17 +40,19 @@ class ParametricDistribution(Distribution, ABC):
 
     Attributes
     ----------
-    shape : Param,
+    shape : Param
         The shape parameter.
-    loc : Param,
+    loc : Param
         The location parameter.
-    scale : Param,
+    scale : Param
         The scale parameter.
-    name : str,
+    shape2: Param
+        Second shape parameter (if the distribution has one).
+    name : str
         The name of the distribution. ("Weibull", "LogNormal", "Normal")
-    _scipy_cdf : function,
+    _scipy_cdf : function
         The cumulative distribution function from scipy. (sts.weibull_min.cdf, ...)
-    _scipy_i_cdf : function,
+    _scipy_i_cdf : function
         The inverse cumulative distribution (or percent-point) function.(sts.weibull_min.ppf, ...)
     _default_shape : float
         The default shape parameter.
@@ -57,6 +60,8 @@ class ParametricDistribution(Distribution, ABC):
         The default loc parameter.
     _default_scale : float
         The default scale parameter.
+    _default_shape2 : float
+        Default shape2 parameter (if the distribution has a second shape parameter).
 
 
     Note
@@ -68,12 +73,13 @@ class ParametricDistribution(Distribution, ABC):
     """
 
     @abstractmethod
-    def __init__(self, shape, loc, scale):
+    def __init__(self, shape, loc, scale, shape2=None):
         """
         Note
         ----
         All parametric distributions can be initalized with 'scale', 'shape'
-        and 'loc' (location) parameters. Implemented distributions are:
+        and 'loc' (location) parameters. Some distribution have a second shape
+        parameter, 'shape2'. Implemented distributions are:
 
         * normal: :math:`f(x) = \\frac{1}{x\\widetilde{\\sigma} \\sqrt{2\\pi}}\\exp \\left[ \\frac{-(\\ln x - \\widetilde{\\mu})^2}{2\\widetilde{\\sigma}^2}\\right]`
 
@@ -81,15 +87,18 @@ class ParametricDistribution(Distribution, ABC):
 
         * log-normal: :math:`f(x) = \\frac{1}{x\\widetilde{\\sigma} \\sqrt{2\\pi}}\\exp \\left[ \\frac{-(\\ln x - \\widetilde{\\mu})^2}{2\\widetilde{\\sigma}^2}\\right]`
 
+        * Exponentiated Weibull:
+
         Their scale, shape, and loc values corerspond to the variables
         in the probability density function in the following manner:
 
         ============  ===================  =================  ================
-        distribution  scale                shape              loc
+        distribution  scale                shape              loc (or shape2)
         ============  ===================  =================  ================
         normal        σ                    --                 μ
         Weibull       α                    β                  γ
         log-normal    e^μ                  σ                  --
+        exp. Weibull  α                    β                  -- instead: γ
         ============  ===================  =================  ================
 
         Parameters
@@ -100,16 +109,20 @@ class ParametricDistribution(Distribution, ABC):
             The location parameter.
         scale : Param,
             The scale parameter.
+        shape2: Param
+            Second shape parameter (if the distribution has one).
         """
         self.shape = shape
         self.loc = loc
         self.scale = scale
+        self.shape2 = shape2
         # The following attributes need to be overwritten by subclasses
         self.name = "Parametric"  # e.g. "Weibull", "Lognormal",  ...
 
         self._default_shape = 1
         self._default_loc = 0
         self._default_scale = 1
+        self._default_shape2 = None
 
         self._valid_shape = {"min" : -np.inf, "strict_greater" : True,
                              "max" : np.inf, "strict_less" : True } # -inf < shape < inf
@@ -117,6 +130,8 @@ class ParametricDistribution(Distribution, ABC):
                            "max" : np.inf, "strict_less" : True }
         self._valid_scale = {"min" : -np.inf, "strict_greater" : True,
                              "max" : np.inf, "strict_less" : True }
+        self._valid_shape2 = {"min" : -np.inf, "strict_greater" : True,
+                             "max" : np.inf, "strict_less" : True }
 
 
     @abstractmethod
@@ -127,20 +142,20 @@ class ParametricDistribution(Distribution, ABC):
     def _scipy_i_cdf(self, probabilities, shape, loc, scale):
         """Overwrite with appropriate i_cdf function from scipy package. """
 
-    def cdf(self, x, rv_values, dependencies):
+    def cdf(self, x, rv_values=None, dependencies=None):
         """
         Calculate the cumulative distribution function.
 
         Parameters
         ----------
-        x : array_like,
+        x : array_like
             Points at which to calculate the cdf.
-        rv_values : array_like,
+        rv_values : array_like
             Values of all random variables in variable space in correct order.
             This can be a 1-dimensional array with length equal to the number of
             random variables N or a 2-dimensional array with shape (N, M).
             If x is an array, M must be len(x).
-        dependencies : tuple,
+        dependencies : tuple
             A 3-element tuple with one entry each for the shape, loc and scale parameters.
             The entry is the index of the random variable the parameter depends on.
             The index order has to be the same as in rv_values.
@@ -152,24 +167,28 @@ class ParametricDistribution(Distribution, ABC):
             Cumulative distribution function evaluated at x under condition rv_values.
         """
 
-        shape_val, loc_val, scale_val = self._get_parameter_values(rv_values, dependencies)
+        shape_val, loc_val, scale_val, shape2_val = self._get_parameter_values(rv_values, dependencies)
+        if shape2_val == None:
+            params = (shape_val, loc_val, scale_val)
+        else:
+            params = (shape_val, loc_val, scale_val, shape2_val)
 
-        return self._scipy_cdf(x, shape_val, loc_val, scale_val)
+        return self._scipy_cdf(x, *params)
 
-    def i_cdf(self, probabilities, rv_values, dependencies):
+    def i_cdf(self, probabilities, rv_values=None, dependencies=None):
         """
         Calculate percent-point function. (inverse cumulative distribution function)
 
         Parameters
         ----------
-        probabilities : array_like,
+        probabilities : array_like
             Probabilities for which to calculate the i_cdf.
-        rv_values : array_like,
+        rv_values : array_like
             Values of all random variables in variable space in correct order.
             This can be a 1-dimensional array with length equal to the number of
             random variables N or a 2-dimensional array with shape (N, M).
             If probabilities is an array, M must be len(probabilities).
-        dependencies : tuple,
+        dependencies : tuple
             A 3-element tuple with one entry each for the shape, loc and scale parameters.
             The entry is the index of the random variable the parameter depends on.
             The index order has to be the same as in rv_values.
@@ -181,9 +200,51 @@ class ParametricDistribution(Distribution, ABC):
             under condition rv_values.
         """
 
-        shape_val, loc_val, scale_val = self._get_parameter_values(rv_values, dependencies)
+        shape_val, loc_val, scale_val, shape2_val = self._get_parameter_values(rv_values, dependencies)
+        if shape2_val == None:
+            params = (shape_val, loc_val, scale_val)
+        else:
+            params = (shape_val, loc_val, scale_val, shape2_val)
 
-        return self._scipy_i_cdf(probabilities, shape_val, loc_val, scale_val)
+        return self._scipy_i_cdf(probabilities, *params)
+
+    def ppf(self, probabilities, rv_values=None, dependencies=None):
+        # Synsynom for i_cdf. Implemented that in external code a ParametricDistribution
+        # object can be used when scipy.stats.rv_continuous.ppf is meant.
+        return self.i_cdf(probabilities, rv_values, dependencies)
+
+    def pdf(self, x, rv_values=None, dependencies=None):
+        """
+        Probability density function.
+
+        Parameters
+        ----------
+        x : array_like
+            Points at which the PDF should be evaluated.
+        rv_values : array_like
+            Values of all random variables in variable space in correct order.
+            This can be a 1-dimensional array with length equal to the number of
+            random variables N or a 2-dimensional array with shape (N, M).
+            If x is an array, M must be len(x).
+        dependencies : tuple
+            A 3-element tuple with one entry each for the shape, loc and scale parameters.
+            The entry is the index of the random variable the parameter depends on.
+            The index order has to be the same as in rv_values.
+
+
+        Returns
+        -------
+        cdf : ndarray,
+            Porbability densities at x under condition rv_values.
+        """
+
+        shape_val, loc_val, scale_val, shape2_val = self._get_parameter_values(rv_values, dependencies)
+        if shape2_val == None:
+            params = (shape_val, loc_val, scale_val)
+        else:
+            params = (shape_val, loc_val, scale_val, shape2_val)
+
+        return self._scipy_pdf(x, *params)
 
     def _get_parameter_values(self, rv_values, dependencies):
         """
@@ -191,31 +252,32 @@ class ParametricDistribution(Distribution, ABC):
 
         Parameters
         ----------
-        rv_values : array_like,
+        rv_values : array_like
             Values of all random variables in variable space in correct order.
-        dependencies : tuple,
-            A 3-element tuple with one entry each for the shape, loc and scale parameters.
+        dependencies : tuple
+            A 4-element tuple with one entry each for the shape, loc and scale parameters.
             The entry is the index of the random variable the parameter depends on.
             The index order has to be the same as in rv_values.
 
         Returns
         -------
-        parameter_vals : tuple,
-            A 3-element tuple with one entry each for the shape, loc and scale parameters.
+        parameter_vals : tuple
+            A 4-element tuple with one entry each for the shape, loc and scale parameters.
             The tuple contains the values of the parameters evaluated under the conditions
             of dependencies.
             The values are either float or lists of float.
         """
-        params = (self.shape, self.loc, self.scale)
-        defaults = (self._default_shape, self._default_loc, self._default_scale)
+        params = (self.shape, self.loc, self.scale, self.shape2)
+        defaults = (self._default_shape, self._default_loc, self._default_scale, self._default_shape2)
         parameter_vals = []
 
         for i, param in enumerate(params):
             if param is None:
                 parameter_vals.append(defaults[i])
-            elif dependencies[i] is None:
+            elif dependencies is None or dependencies[i] is None:
                 parameter_vals.append(param(None))
-                self._check_parameter_value(i, parameter_vals[-1])
+                if parameter_vals[-1] is not None:
+                    self._check_parameter_value(i, parameter_vals[-1])
             else:
                 parameter_vals.append(param(rv_values[dependencies[i]]))
                 try: # if list fo values iterate over values
@@ -232,10 +294,10 @@ class ParametricDistribution(Distribution, ABC):
 
         Parameters
         ----------
-        param_index : int,
+        param_index : int
             Index of parameter.
             (0 = 'shape', 1 = 'loc', 2 = 'scale')
-        param_value : float,
+        param_value : float
             Value of parameter.
 
         Raises
@@ -251,8 +313,11 @@ class ParametricDistribution(Distribution, ABC):
             valid = self._valid_loc
             param_name = LOCATION_STRING
         elif param_index == 2:
-            valid = self._valid_shape
+            valid = self._valid_scale
             param_name = SCALE_STRING
+        elif param_index == 3:
+            valid = self._valid_shape2
+            param_name = SHAPE2_STRING
 
         if valid["strict_greater"]:
             if not param_value > valid["min"]:
@@ -278,7 +343,8 @@ class ParametricDistribution(Distribution, ABC):
 
         def __str__(self):
             return  "ParametricDistribution with shape={}, loc={}," \
-                    "scale={}.".format(self.shape, self.loc, self.scale)
+                    "scale={}, shape2={}.".format(
+                self.shape, self.loc, self.scale, self.shape2)
 
     @staticmethod
     def param_name_to_index(param_name):
@@ -288,12 +354,12 @@ class ParametricDistribution(Distribution, ABC):
 
         Parameters
         ----------
-        param_name : str,
+        param_name : str
             The name of the parameter, must be 'shape', 'loc', or 'scale'.
 
         Returns
         -------
-        param_index : int,
+        param_index : int
             The index corresponding to the name of the parameter as it is
             internally defined in viroconcom.
         """
@@ -304,6 +370,8 @@ class ParametricDistribution(Distribution, ABC):
             param_index = 1
         elif param_name == SCALE_STRING:
             param_index = 2
+        elif param_name == SHAPE2_STRING:
+            param_index = 3
         else:
             raise ValueError("Wrong parameter name. The param_name variable "
                              "must be either 'shape', 'loc' or 'scale', however,"
@@ -348,6 +416,202 @@ class WeibullDistribution(ParametricDistribution):
         return sts.weibull_min.ppf(probabilities, c=shape, loc=loc, scale=scale)
 
 
+class ExponentiatedWeibullDistribution(ParametricDistribution):
+    """
+    An exponentiated Weibull distribution.
+
+    Note
+    -----
+    We use the parametrization that is also used in
+    https://arxiv.org/pdf/1911.12835.pdf .
+    """
+
+    def __init__(self, shape=None, loc=None, scale=None, shape2=None):
+        super().__init__(shape, loc, scale, shape2)
+        self.name = "ExponentiatedWeibull"
+        self._valid_shape = {"min" : 0, "strict_greater" : True,
+                             "max" : np.inf, "strict_less" : True }
+        self._valid_scale = {"min" : 0, "strict_greater" : True,
+                             "max" : np.inf, "strict_less" : True }
+        self._valid_shape2 = {"min" : 0, "strict_greater" : True,
+                             "max" : np.inf, "strict_less" : True }
+
+    def _scipy_cdf(self, x, shape, loc, scale, shape2):
+        x = np.array(x)
+        # Ensure x> 0. In Matlab syntax do: x(x < 0) = 0
+        indices = np.argwhere(x < 0)
+        np.put(x, indices, np.zeros(indices.size))
+        p = np.power(1 - np.exp(np.multiply(-1, np.power(np.divide(x,  scale), shape))), shape2)
+        return p
+
+    def _scipy_i_cdf(self, p, shape, loc, scale, shape2):
+        p = np.array(p)
+        if np.any(np.greater(p, 1)):
+            p = np.nan
+        if np.any(np.less(p, 0)):
+            p = np.nan
+        # In Matlab syntax: x = scale .* (-1 .* log(1 - p.^(1 ./ shape2))).^(1 ./ shape);
+        x = np.multiply(scale, np.power(np.multiply(-1, np.log(1 - np.power(p, np.divide(1, shape2)))), np.divide(1, shape)))
+        return x
+
+    def _scipy_pdf(self, x, shape, loc, scale, shape2):
+        """
+        Probability density function of the exponentiated Weibull distribution.
+
+        The parametrization from https://arxiv.org/pdf/1911.12835.pdf is used.
+
+        Parameters
+        ----------
+        x : array_like
+            Position where the PDF should be evaluated.
+        shape: float
+            beta in https://arxiv.org/pdf/1911.12835.pdf .
+        loc : float
+            The distribution does not have a location parameter.
+        scale : float
+            alpha in https://arxiv.org/pdf/1911.12835.pdf .
+        shape2 : float
+            delta in https://arxiv.org/pdf/1911.12835.pdf .
+
+        Returns
+        -------
+        f : array_like
+            Probability density values.
+        """
+
+        x = np.array(x)
+        # In Matlab syntax: f = delta .* beta ./ alpha .* (x ./ alpha).^
+        # (beta - 1) .* (1 - exp(-1 * (x ./ alpha).^beta)).^(delta - 1) .*
+        # exp(-1 .* (x ./ alpha).^beta);
+        a = scale
+        b = shape
+        d = shape2
+        term1 = d * np.divide(b, a) * np.power(np.divide(x, a), b - 1)
+        term2 = np.power(1 - np.exp(-1 * np.power(np.divide(x, a), b)), d - 1)
+        term3 = np.exp(-1 * np.power(np.divide(x, a), b))
+        f = np.multiply(term1, np.multiply(term2, term3))
+        f = np.array(f) # Ensure that f is an numpy array, also if x is 1D.
+
+        # Ensure that PDF(negative value) = 0
+        f[x < 0] = 0
+
+        return f
+
+    def fit(self, sample, method='WLS', shape=None, loc=None, scale=None, shape2=None):
+        """
+
+        Parameters
+        ----------
+        sample : array_like,
+            The data that should be used to fit the distribution to it.
+        method : str,
+            Fitting method, either 'MLE' for maximum likelihood estimation or
+            'WLS' for weighted least squares, similar to: https://arxiv.org/pdf/1911.12835.pdf
+        shape : float, optional
+            If given the shape parameter won't be fitted.
+        loc : Not used, must be None
+            The exponentiated Weibull distribution does not have a location
+            parameter. However, for consistency we have it as a parameter at the
+            expected place.
+        scale : float, optional
+            If given the scale parameter won't be fitted.
+        shape2 : float, optional
+            If given the second shape parametr won't be fitted.
+
+        Returns
+        -------
+        params: 4-dimensional tuple
+         Holds (shape, loc=None, scale, shape2).
+
+        """
+        def estimateAlphaBetaWithWLS(delta, xi, pi, do_return_parameters=True):
+            """
+            Translated from the Matlab implementation available at
+            https://github.com/ahaselsteiner/exponentiated-weibull/blob/issue%231/ExponentiatedWeibull.m#L210
+
+            Parameters
+            ----------
+            delta : float
+                shape2 parameter of the distribution
+            xi : array_like
+                Sorted sample.
+            pi : array_like
+                Probabilities of the sorted sample.
+
+            Returns
+            -------
+            (WLSError, pHat) where pHat are the parameter estimates.
+            """
+            xi = np.array(xi)
+            pi = np.array(pi)
+
+
+            # First, transform xi and pi to get a lienar relationship.
+            xstar_i = np.log10(xi)
+            power_term = np.power(pi, np.divide(1.0, delta))
+            pstar_i = np.log10(-1.0 * np.log(1.0 - power_term))
+
+            # Define the weights.
+            wi = np.divide(np.power(xi, 2), sum(np.power(xi, 2)))
+
+            # Estimate the parameters alphaHat and betaHat.
+            pstarbar = sum(np.multiply(wi, pstar_i))
+            xstarbar = sum(np.multiply(wi, xstar_i))
+            temp1 = sum(np.multiply(wi, np.multiply(pstar_i, xstar_i))) - np.multiply(pstarbar, xstarbar)
+            temp2 = sum(np.multiply(wi, np.power(pstar_i, 2))) - np.power(pstarbar, 2)
+            bHat = np.divide(temp1, temp2)
+            aHat = xstarbar - bHat * pstarbar
+            alphaHat = np.power(10, aHat)
+            betaHat = 1.0 / bHat
+            pHat = (alphaHat, betaHat, delta)
+
+            # Compute the weighted least squares error.
+            xiHat = np.multiply(alphaHat, np.power(np.multiply(-1, np.log(1 - np.power(pi, 1.0 / delta))), 1.0 / betaHat))
+            WLSError = sum(np.multiply(wi, np.power(xi - xiHat, 2.0)))
+
+            if do_return_parameters:
+                return pHat, WLSError
+            else:
+                return WLSError # If the function shall be used as cost function.
+
+        params = (shape, loc, scale, shape2)
+        # Code written based on the Matlab implementation available here:
+        # https://github.com/ahaselsteiner/exponentiated-weibull/blob/issue%231/ExponentiatedWeibull.m
+        isFixed = (shape is not None, loc is not None, scale is not None, shape2 is not None)
+        if method == 'WLS': # Weighted least squares
+            n = sample.size
+            i = np.array(range(n)) + 1
+            pi = np.divide((i - 0.5), n)
+            xi = np.sort(sample)
+            delta0 = 2
+            if sum(isFixed) == 0:
+                shape2 = scipy.optimize.fmin(estimateAlphaBetaWithWLS, delta0, args=(xi, pi, False))
+                shape2 = shape2[0] # Returns an 1x1 array, however, we want a float.
+                pHat, WLSError = estimateAlphaBetaWithWLS(shape2, xi, pi)
+            elif sum(isFixed) == 1:
+                if isFixed[3] == 1:
+                       pHat, WLSError = estimateAlphaBetaWithWLS(shape2, xi, pi)
+                else:
+                    err_msg = "Error. Fixing shape or scale is not implemented yet."
+                    raise NotImplementedError(err_msg)
+            elif sum(isFixed == 2):
+                err_msg = "Error. Fixing multiple parameters is not implemented yet."
+                raise NotImplementedError(err_msg)
+            else:
+                err_msg = "Error. At least one parameter needs to be free to fit it."
+                raise NotImplementedError(err_msg)
+
+        params = (pHat[1], loc, pHat[0], shape2) # shape, location, scale, shape2
+        constantParams = (ConstantParam(pHat[1]), # shape parameter.
+                          ConstantParam(loc), # location parameter.
+                          ConstantParam(pHat[0]), # scale parameter.
+                          ConstantParam(shape2)) # Second shape parameter
+
+        self.__init__(*constantParams)
+
+        return params
+
+
 class LognormalDistribution(ParametricDistribution):
     """
     A Lognormal distribution.
@@ -399,7 +663,7 @@ class LognormalDistribution(ParametricDistribution):
                 # Keep possibly already existing wrapper
                 scale_wrapper = Wrapper(np.exp, self.mu._wrapper)
                 # Create new FunctionParam so the passed one does not get altered
-                scale = FunctionParam(_a, _b, _c, "f1", wrapper=scale_wrapper)
+                scale = FunctionParam(self.mu.func_name, _a, _b, _c, wrapper=scale_wrapper)
                 scale._func = _func
             else:
                 scale = ConstantParam(np.exp(self.mu(None)))
@@ -471,11 +735,11 @@ class MultivariateDistribution():
 
     Attributes
     ----------
-    distributions : list of Distribution,
+    distributions : list of Distribution
         A list containing the distributions.
-    dependencies : list of tuples,
+    dependencies : list of tuples
         A list containing a dependency tuple for each distribution.
-    n_dim : int,
+    n_dim : int
         The number of distributions. Equal to len(distributions).
     """
 
@@ -483,9 +747,9 @@ class MultivariateDistribution():
         """
         Parameters
         ----------
-        distributions : list of Distribution,
+        distributions : list of Distribution
             A list containing distributions.
-        dependencies : list of tuples,
+        dependencies : list of tuples
             A list with one dependency tuple for each distribution.
         """
         self.distributions = []
@@ -502,9 +766,9 @@ class MultivariateDistribution():
 
         Parameters
         ----------
-        distributions : ``Distribution`` or list of ``Distribution``,
+        distributions : ``Distribution`` or list of ``Distribution``
             A distribution or list containing distributions.
-        dependencies : tuple or list of tuples,
+        dependencies : tuple or list of tuples
             A dependency tuple or list with one dependency tuple for each distribution.
 
         """
@@ -555,14 +819,14 @@ class MultivariateDistribution():
         """
         for dimension, dependency in enumerate(self.dependencies):
             if(dep_is_iter_of_tuple):
-                if len(dependency) != 3:
-                    return ("The length of the dependency in dimension '{}' was not three.".format(dimension))
+                if len(dependency) < 3:
+                    return ("The length of the dependency in dimension '{}' was less than three.".format(dimension))
                 elif not all([True if d is None or d < dimension else False for d in dependency]):
                     return ("The dependency of dimension '{}' must have smaller index than dimension or 'None'.".format(dimension))
                 elif not all([True if d is None or d >= 0 else False for d in dependency]):
                     return ("The dependency of dimension '{}' must be positive or 'None'.".format(dimension))
-            elif len(self.dependencies) != 3:
-                return ("The length of dependencies was not three.")
+            elif len(self.dependencies) < 3:
+                return ("The length of dependencies was less than three.")
         return None
 
     def cell_averaged_joint_pdf(self, coords):
@@ -573,13 +837,13 @@ class MultivariateDistribution():
 
         Parameters
         ----------
-        coords : array_like,
+        coords : array_like
             List of the sampling points of the random variables.
             The length of coords has to equal self.n_dim.
 
         Returns
         -------
-        fbar : ndarray,
+        fbar : ndarray
             Cell averaged joint probabilty density function evaluated at coords.
             It is a self.n_dim dimensional array,
             with shape (len(coords[0]), len(coords[1]), ...)
@@ -601,17 +865,17 @@ class MultivariateDistribution():
 
         Parameters
         ----------
-        dist_index : int,
+        dist_index : int
             The index of the distribution to calculate the pdf of,
             according to order of self.distributions.
-        coords : array_like,
+        coords : array_like
             List of the sampling points of the random variables.
             The pdf is calculated at coords[dist_index].
             The length of coords has to equal self.n_dim.
 
         Returns
         -------
-        fbar : ndarray,
+        fbar : ndarray
             Cell averaged probabilty density function evaluated at coords[dist_index].
             It is a self.n_dim dimensional array.
         """
@@ -656,14 +920,14 @@ class MultivariateDistribution():
 
         Parameters
         ----------
-        var_symbols : list,
+        var_symbols : list
             List of the random variable symbols, the first letter should be
              capitalized and further characters will be converged to subscripts,
              an example would be  ['Hs', 'Tp', 'V']
 
         Returns
         -------
-        latex_string : String,
+        latex_string : str
             The joint pdf in latex format (without $)
             E.g. f(h_s,t_p)=f_{H_s}(h_s)=
         """
@@ -758,13 +1022,15 @@ class MultivariateDistribution():
                                 realization_symbols[i] + r"-" + loc_name + \
                                 r")^2}{2" + scale_name + r"^2}\right]"
             elif self.distributions[i].name == "Lognormal":
-                # The shape and scale naming for sigma and mu is not inuitive.
-                # Intuitive would be as with the Normal pdf --> sigma = scale,
-                # mu = location. This should be checked
                 shape_name = r"\tilde{\sigma}_{" + realization_symbols[i] + "}"
-                # Scale could also be interpeted as exp^(mu), but here for
-                # simplicity we use the same variable name
-                scale_name = r"\tilde{\mu}_{" + realization_symbols[i] + "}"
+
+                # Here for simplicity we save mu in the 'scale_value'
+                # variable, although we know scale = exp(mu)
+                if hasattr(self.distributions[i], 'mu'):
+                    scale_name = r"\tilde{\mu}_{" + realization_symbols[i] + "}"
+                else:
+                    scale_name = r"\exp{\tilde{\mu}}_{" + realization_symbols[i] + "}"
+
                 latex_string += r"\dfrac{1}{" + realization_symbols[i] + \
                                 r"\tilde{\sigma}_{" \
                         + realization_symbols[i] + \
@@ -777,7 +1043,14 @@ class MultivariateDistribution():
             if scale_name:
                 latex_string = r"\quad\text{ with }"
                 if self.distributions[i].name == "Lognormal":
-                    scale_value = str(self.distributions[i].mu)
+
+                    if hasattr(self.distributions[i], 'mu'):
+                        # Here for simplicity we save mu in the 'scale_value'
+                        # variable, although we know scale = exp(mu)
+                        scale_value = str(self.distributions[i].mu)
+                    else:
+                        scale_value = str(self.distributions[i].scale)
+
                 else:
                     scale_value = str(self.distributions[i].scale)
                 for j in range(self.n_dim):
@@ -870,15 +1143,15 @@ class KernelDensityDistribution(Distribution):
 
         Parameters
         ----------
-        x : array_like,
+        x : array_like
             Points at which to calculate the cdf.
-        rv_values : array_like,
+        rv_values : array_like
             Values of all random variables in variable space in correct order.
             This can be a 1-dimensional array with length equal to the number of
             random variables N or a 2-dimensional array with shape (N, M).
             If x is an array, M must be len(x).
             --Not used for Kernel Density--
-        dependencies : tuple,
+        dependencies : tuple
             A 3-element tuple with one entry each for the shape, loc and scale parameters.
             The entry is the index of the random variable the parameter depends on.
             The index order has to be the same as in rv_values.
@@ -886,7 +1159,7 @@ class KernelDensityDistribution(Distribution):
 
         Returns
         -------
-        cdf : ndarray,
+        cdf : ndarray
             Cumulative distribution function evaluated at x.
         """
         result = []
@@ -906,15 +1179,15 @@ class KernelDensityDistribution(Distribution):
 
         Parameters
         ----------
-        probabilities : array_like,
+        probabilities : array_like
             Probabilities for which to calculate the i_cdf.
-        rv_values : array_like,
+        rv_values : array_like
             Values of all random variables in variable space in correct order.
             This can be a 1-dimensional array with length equal to the number of
             random variables N or a 2-dimensional array with shape (N, M).
             If probabilities is an array, M must be len(probabilities).
             --Not used for Kernel Density--
-        dependencies : tuple,
+        dependencies : tuple
             A 3-element tuple with one entry each for the shape, loc and scale parameters.
             The entry is the index of the random variable the parameter depends on.
             The index order has to be the same as in rv_values.
